@@ -16,13 +16,8 @@ class Collection(object):
 
     name = None
 
-    def _method_not_allowed(self):
-        """INTERNAL: placeholder for a method that is called with the wrong
-        HTTP method."""
-        raise NotImplementedError
-
-    def setup(self):
+    def _setup(self):
         """Called just before a request method is called."""
 
-    def close(self):
+    def _teardown(self):
         """Called after a request has been finished."""
